/*
 *   moousertools-prefs.h
 *
 *   Copyright (C) 2004-2010 by Yevgen Muntyan <emuntyan@users.sourceforge.net>
 *
 *   This file is part of medit.  medit is free software; you can
 *   redistribute it and/or modify it under the terms of the
 *   GNU Lesser General Public License as published by the
 *   Free Software Foundation; either version 2.1 of the License,
 *   or (at your option) any later version.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with medit.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MOO_USER_TOOLS_PREFS_H
#define MOO_USER_TOOLS_PREFS_H

#include <gtk/gtk.h>

G_BEGIN_DECLS


GtkWidget *moo_user_tools_prefs_page_new (void);


G_END_DECLS

#endif /* MOO_USER_TOOLS_PREFS_H */
